"""
    .. Copyright:
        Copyright Wirepas Ltd 2019 licensed under Apache License, Version 2.0
        See file LICENSE for full license details.
"""

__author__ = "Wirepas Ltd"
__author_email__ = "opensource@wirepas.com"
__classifiers__ = [
    "Development Status :: 5 - Production/Stable",
    "Intended Audience :: Developers",
    "License :: OSI Approved :: Apache Software License",
    "Topic :: Software Development :: Libraries",
    "Programming Language :: Python :: 3",
]
__copyright__ = "2020 Wirepas Ltd"
__description__ = "Wrapper interfaces to interact with Backend to/from Gateway API."
__keywords__ = "wirepas connectivity iot mesh gateway backend"
__license__ = "Apache-2"
__pkg_name__ = "wirepas_mesh_messaging"
__title__ = "Wirepas Messaging For Mesh access"
__url__ = "https://github.com/wirepas/backend-apis/tree/master/gateway_to_backend"
__version__ = "1.1"
__warning_msg__ = """
***********************************************************************
* WARNING:
*     You are using the pure python protobuf implementation.
*     For better results, please consider using the cpp version.
*     For more information please consult:
*     https://github.com/protocolbuffers/protobuf/tree/master/python
***********************************************************************
"""
