# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: otap_message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import wp_global_pb2 as wp__global__pb2
import error_pb2 as error__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='otap_message.proto',
  package='wirepas.proto.gateway_api',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12otap_message.proto\x12\x19wirepas.proto.gateway_api\x1a\x0fwp_global.proto\x1a\x0b\x65rror.proto\"7\n\x0eScratchpadInfo\x12\x0b\n\x03len\x18\x01 \x02(\r\x12\x0b\n\x03\x63rc\x18\x02 \x02(\r\x12\x0b\n\x03seq\x18\x03 \x02(\r\"\xda\x01\n\x19TargetScratchpadAndAction\x12;\n\x06\x61\x63tion\x18\x01 \x02(\x0e\x32+.wirepas.proto.gateway_api.ScratchpadAction\x12\x17\n\x0ftarget_sequence\x18\x02 \x01(\r\x12\x12\n\ntarget_crc\x18\x03 \x01(\r\x12;\n\x05\x64\x65lay\x18\x04 \x01(\x0e\x32*.wirepas.proto.gateway_api.ProcessingDelayH\x00\x12\r\n\x03raw\x18\x05 \x01(\rH\x00\x42\x07\n\x05param\"R\n\x16GetScratchpadStatusReq\x12\x38\n\x06header\x18\x01 \x02(\x0b\x32(.wirepas.proto.gateway_api.RequestHeader\"\xd2\x03\n\x17GetScratchpadStatusResp\x12\x39\n\x06header\x18\x01 \x02(\x0b\x32).wirepas.proto.gateway_api.ResponseHeader\x12\x44\n\x11stored_scratchpad\x18\x02 \x01(\x0b\x32).wirepas.proto.gateway_api.ScratchpadInfo\x12\x42\n\rstored_status\x18\x03 \x01(\x0e\x32+.wirepas.proto.gateway_api.ScratchpadStatus\x12>\n\x0bstored_type\x18\x04 \x01(\x0e\x32).wirepas.proto.gateway_api.ScratchpadType\x12G\n\x14processed_scratchpad\x18\x05 \x01(\x0b\x32).wirepas.proto.gateway_api.ScratchpadInfo\x12\x18\n\x10\x66irmware_area_id\x18\x06 \x01(\r\x12O\n\x11target_and_action\x18\x07 \x01(\x0b\x32\x34.wirepas.proto.gateway_api.TargetScratchpadAndAction\"p\n\x13UploadScratchpadReq\x12\x38\n\x06header\x18\x01 \x02(\x0b\x32(.wirepas.proto.gateway_api.RequestHeader\x12\x0b\n\x03seq\x18\x02 \x02(\r\x12\x12\n\nscratchpad\x18\x03 \x01(\x0c\"Q\n\x14UploadScratchpadResp\x12\x39\n\x06header\x18\x01 \x02(\x0b\x32).wirepas.proto.gateway_api.ResponseHeader\"P\n\x14ProcessScratchpadReq\x12\x38\n\x06header\x18\x01 \x02(\x0b\x32(.wirepas.proto.gateway_api.RequestHeader\"R\n\x15ProcessScratchpadResp\x12\x39\n\x06header\x18\x01 \x02(\x0b\x32).wirepas.proto.gateway_api.ResponseHeader\"\xac\x01\n\x1fSetScratchpadTargetAndActionReq\x12\x38\n\x06header\x18\x01 \x02(\x0b\x32(.wirepas.proto.gateway_api.RequestHeader\x12O\n\x11target_and_action\x18\x02 \x02(\x0b\x32\x34.wirepas.proto.gateway_api.TargetScratchpadAndAction\"]\n SetScratchpadTargetAndActionResp\x12\x39\n\x06header\x18\x01 \x02(\x0b\x32).wirepas.proto.gateway_api.ResponseHeader*5\n\x0eScratchpadType\x12\t\n\x05\x42LANK\x10\x01\x12\x0b\n\x07PRESENT\x10\x02\x12\x0b\n\x07PROCESS\x10\x03*3\n\x10ScratchpadStatus\x12\x0b\n\x07SUCCESS\x10\x01\x12\x07\n\x03NEW\x10\x02\x12\t\n\x05\x45RROR\x10\x03*\x99\x01\n\x10ScratchpadAction\x12\x12\n\x0eUNKNOWN_ACTION\x10\x00\x12\x0b\n\x07NO_OTAP\x10\x01\x12\x12\n\x0ePROPAGATE_ONLY\x10\x02\x12\x19\n\x15PROPAGATE_AND_PROCESS\x10\x03\x12$\n PROPAGATE_AND_PROCESS_WITH_DELAY\x10\x04\x12\x0f\n\x0bLEGACY_OTAP\x10\x05*\x90\x01\n\x0fProcessingDelay\x12\x11\n\rUNKNOWN_DELAY\x10\x00\x12\x0f\n\x0bTEN_MINUTES\x10\x01\x12\x12\n\x0eTHIRTY_MINUTES\x10\x02\x12\x0c\n\x08ONE_HOUR\x10\x03\x12\r\n\tSIX_HOURS\x10\x04\x12\x0b\n\x07ONE_DAY\x10\x05\x12\x0c\n\x08TWO_DAYS\x10\x06\x12\r\n\tFIVE_DAYS\x10\x07'
  ,
  dependencies=[wp__global__pb2.DESCRIPTOR,error__pb2.DESCRIPTOR,])

_SCRATCHPADTYPE = _descriptor.EnumDescriptor(
  name='ScratchpadType',
  full_name='wirepas.proto.gateway_api.ScratchpadType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BLANK', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESENT', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROCESS', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1543,
  serialized_end=1596,
)
_sym_db.RegisterEnumDescriptor(_SCRATCHPADTYPE)

ScratchpadType = enum_type_wrapper.EnumTypeWrapper(_SCRATCHPADTYPE)
_SCRATCHPADSTATUS = _descriptor.EnumDescriptor(
  name='ScratchpadStatus',
  full_name='wirepas.proto.gateway_api.ScratchpadStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEW', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1598,
  serialized_end=1649,
)
_sym_db.RegisterEnumDescriptor(_SCRATCHPADSTATUS)

ScratchpadStatus = enum_type_wrapper.EnumTypeWrapper(_SCRATCHPADSTATUS)
_SCRATCHPADACTION = _descriptor.EnumDescriptor(
  name='ScratchpadAction',
  full_name='wirepas.proto.gateway_api.ScratchpadAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ACTION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_OTAP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPAGATE_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPAGATE_AND_PROCESS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPAGATE_AND_PROCESS_WITH_DELAY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEGACY_OTAP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1652,
  serialized_end=1805,
)
_sym_db.RegisterEnumDescriptor(_SCRATCHPADACTION)

ScratchpadAction = enum_type_wrapper.EnumTypeWrapper(_SCRATCHPADACTION)
_PROCESSINGDELAY = _descriptor.EnumDescriptor(
  name='ProcessingDelay',
  full_name='wirepas.proto.gateway_api.ProcessingDelay',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_DELAY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEN_MINUTES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THIRTY_MINUTES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONE_HOUR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIX_HOURS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONE_DAY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TWO_DAYS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIVE_DAYS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1808,
  serialized_end=1952,
)
_sym_db.RegisterEnumDescriptor(_PROCESSINGDELAY)

ProcessingDelay = enum_type_wrapper.EnumTypeWrapper(_PROCESSINGDELAY)
BLANK = 1
PRESENT = 2
PROCESS = 3
SUCCESS = 1
NEW = 2
ERROR = 3
UNKNOWN_ACTION = 0
NO_OTAP = 1
PROPAGATE_ONLY = 2
PROPAGATE_AND_PROCESS = 3
PROPAGATE_AND_PROCESS_WITH_DELAY = 4
LEGACY_OTAP = 5
UNKNOWN_DELAY = 0
TEN_MINUTES = 1
THIRTY_MINUTES = 2
ONE_HOUR = 3
SIX_HOURS = 4
ONE_DAY = 5
TWO_DAYS = 6
FIVE_DAYS = 7



_SCRATCHPADINFO = _descriptor.Descriptor(
  name='ScratchpadInfo',
  full_name='wirepas.proto.gateway_api.ScratchpadInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='len', full_name='wirepas.proto.gateway_api.ScratchpadInfo.len', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc', full_name='wirepas.proto.gateway_api.ScratchpadInfo.crc', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='wirepas.proto.gateway_api.ScratchpadInfo.seq', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=134,
)


_TARGETSCRATCHPADANDACTION = _descriptor.Descriptor(
  name='TargetScratchpadAndAction',
  full_name='wirepas.proto.gateway_api.TargetScratchpadAndAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='wirepas.proto.gateway_api.TargetScratchpadAndAction.action', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_sequence', full_name='wirepas.proto.gateway_api.TargetScratchpadAndAction.target_sequence', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_crc', full_name='wirepas.proto.gateway_api.TargetScratchpadAndAction.target_crc', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='wirepas.proto.gateway_api.TargetScratchpadAndAction.delay', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='wirepas.proto.gateway_api.TargetScratchpadAndAction.raw', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='param', full_name='wirepas.proto.gateway_api.TargetScratchpadAndAction.param',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=137,
  serialized_end=355,
)


_GETSCRATCHPADSTATUSREQ = _descriptor.Descriptor(
  name='GetScratchpadStatusReq',
  full_name='wirepas.proto.gateway_api.GetScratchpadStatusReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.GetScratchpadStatusReq.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=439,
)


_GETSCRATCHPADSTATUSRESP = _descriptor.Descriptor(
  name='GetScratchpadStatusResp',
  full_name='wirepas.proto.gateway_api.GetScratchpadStatusResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.GetScratchpadStatusResp.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_scratchpad', full_name='wirepas.proto.gateway_api.GetScratchpadStatusResp.stored_scratchpad', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_status', full_name='wirepas.proto.gateway_api.GetScratchpadStatusResp.stored_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_type', full_name='wirepas.proto.gateway_api.GetScratchpadStatusResp.stored_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processed_scratchpad', full_name='wirepas.proto.gateway_api.GetScratchpadStatusResp.processed_scratchpad', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firmware_area_id', full_name='wirepas.proto.gateway_api.GetScratchpadStatusResp.firmware_area_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_and_action', full_name='wirepas.proto.gateway_api.GetScratchpadStatusResp.target_and_action', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=442,
  serialized_end=908,
)


_UPLOADSCRATCHPADREQ = _descriptor.Descriptor(
  name='UploadScratchpadReq',
  full_name='wirepas.proto.gateway_api.UploadScratchpadReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.UploadScratchpadReq.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='wirepas.proto.gateway_api.UploadScratchpadReq.seq', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scratchpad', full_name='wirepas.proto.gateway_api.UploadScratchpadReq.scratchpad', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=1022,
)


_UPLOADSCRATCHPADRESP = _descriptor.Descriptor(
  name='UploadScratchpadResp',
  full_name='wirepas.proto.gateway_api.UploadScratchpadResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.UploadScratchpadResp.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1024,
  serialized_end=1105,
)


_PROCESSSCRATCHPADREQ = _descriptor.Descriptor(
  name='ProcessScratchpadReq',
  full_name='wirepas.proto.gateway_api.ProcessScratchpadReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.ProcessScratchpadReq.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1187,
)


_PROCESSSCRATCHPADRESP = _descriptor.Descriptor(
  name='ProcessScratchpadResp',
  full_name='wirepas.proto.gateway_api.ProcessScratchpadResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.ProcessScratchpadResp.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1189,
  serialized_end=1271,
)


_SETSCRATCHPADTARGETANDACTIONREQ = _descriptor.Descriptor(
  name='SetScratchpadTargetAndActionReq',
  full_name='wirepas.proto.gateway_api.SetScratchpadTargetAndActionReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.SetScratchpadTargetAndActionReq.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_and_action', full_name='wirepas.proto.gateway_api.SetScratchpadTargetAndActionReq.target_and_action', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1274,
  serialized_end=1446,
)


_SETSCRATCHPADTARGETANDACTIONRESP = _descriptor.Descriptor(
  name='SetScratchpadTargetAndActionResp',
  full_name='wirepas.proto.gateway_api.SetScratchpadTargetAndActionResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.SetScratchpadTargetAndActionResp.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1448,
  serialized_end=1541,
)

_TARGETSCRATCHPADANDACTION.fields_by_name['action'].enum_type = _SCRATCHPADACTION
_TARGETSCRATCHPADANDACTION.fields_by_name['delay'].enum_type = _PROCESSINGDELAY
_TARGETSCRATCHPADANDACTION.oneofs_by_name['param'].fields.append(
  _TARGETSCRATCHPADANDACTION.fields_by_name['delay'])
_TARGETSCRATCHPADANDACTION.fields_by_name['delay'].containing_oneof = _TARGETSCRATCHPADANDACTION.oneofs_by_name['param']
_TARGETSCRATCHPADANDACTION.oneofs_by_name['param'].fields.append(
  _TARGETSCRATCHPADANDACTION.fields_by_name['raw'])
_TARGETSCRATCHPADANDACTION.fields_by_name['raw'].containing_oneof = _TARGETSCRATCHPADANDACTION.oneofs_by_name['param']
_GETSCRATCHPADSTATUSREQ.fields_by_name['header'].message_type = wp__global__pb2._REQUESTHEADER
_GETSCRATCHPADSTATUSRESP.fields_by_name['header'].message_type = wp__global__pb2._RESPONSEHEADER
_GETSCRATCHPADSTATUSRESP.fields_by_name['stored_scratchpad'].message_type = _SCRATCHPADINFO
_GETSCRATCHPADSTATUSRESP.fields_by_name['stored_status'].enum_type = _SCRATCHPADSTATUS
_GETSCRATCHPADSTATUSRESP.fields_by_name['stored_type'].enum_type = _SCRATCHPADTYPE
_GETSCRATCHPADSTATUSRESP.fields_by_name['processed_scratchpad'].message_type = _SCRATCHPADINFO
_GETSCRATCHPADSTATUSRESP.fields_by_name['target_and_action'].message_type = _TARGETSCRATCHPADANDACTION
_UPLOADSCRATCHPADREQ.fields_by_name['header'].message_type = wp__global__pb2._REQUESTHEADER
_UPLOADSCRATCHPADRESP.fields_by_name['header'].message_type = wp__global__pb2._RESPONSEHEADER
_PROCESSSCRATCHPADREQ.fields_by_name['header'].message_type = wp__global__pb2._REQUESTHEADER
_PROCESSSCRATCHPADRESP.fields_by_name['header'].message_type = wp__global__pb2._RESPONSEHEADER
_SETSCRATCHPADTARGETANDACTIONREQ.fields_by_name['header'].message_type = wp__global__pb2._REQUESTHEADER
_SETSCRATCHPADTARGETANDACTIONREQ.fields_by_name['target_and_action'].message_type = _TARGETSCRATCHPADANDACTION
_SETSCRATCHPADTARGETANDACTIONRESP.fields_by_name['header'].message_type = wp__global__pb2._RESPONSEHEADER
DESCRIPTOR.message_types_by_name['ScratchpadInfo'] = _SCRATCHPADINFO
DESCRIPTOR.message_types_by_name['TargetScratchpadAndAction'] = _TARGETSCRATCHPADANDACTION
DESCRIPTOR.message_types_by_name['GetScratchpadStatusReq'] = _GETSCRATCHPADSTATUSREQ
DESCRIPTOR.message_types_by_name['GetScratchpadStatusResp'] = _GETSCRATCHPADSTATUSRESP
DESCRIPTOR.message_types_by_name['UploadScratchpadReq'] = _UPLOADSCRATCHPADREQ
DESCRIPTOR.message_types_by_name['UploadScratchpadResp'] = _UPLOADSCRATCHPADRESP
DESCRIPTOR.message_types_by_name['ProcessScratchpadReq'] = _PROCESSSCRATCHPADREQ
DESCRIPTOR.message_types_by_name['ProcessScratchpadResp'] = _PROCESSSCRATCHPADRESP
DESCRIPTOR.message_types_by_name['SetScratchpadTargetAndActionReq'] = _SETSCRATCHPADTARGETANDACTIONREQ
DESCRIPTOR.message_types_by_name['SetScratchpadTargetAndActionResp'] = _SETSCRATCHPADTARGETANDACTIONRESP
DESCRIPTOR.enum_types_by_name['ScratchpadType'] = _SCRATCHPADTYPE
DESCRIPTOR.enum_types_by_name['ScratchpadStatus'] = _SCRATCHPADSTATUS
DESCRIPTOR.enum_types_by_name['ScratchpadAction'] = _SCRATCHPADACTION
DESCRIPTOR.enum_types_by_name['ProcessingDelay'] = _PROCESSINGDELAY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScratchpadInfo = _reflection.GeneratedProtocolMessageType('ScratchpadInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCRATCHPADINFO,
  '__module__' : 'otap_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.ScratchpadInfo)
  })
_sym_db.RegisterMessage(ScratchpadInfo)

TargetScratchpadAndAction = _reflection.GeneratedProtocolMessageType('TargetScratchpadAndAction', (_message.Message,), {
  'DESCRIPTOR' : _TARGETSCRATCHPADANDACTION,
  '__module__' : 'otap_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.TargetScratchpadAndAction)
  })
_sym_db.RegisterMessage(TargetScratchpadAndAction)

GetScratchpadStatusReq = _reflection.GeneratedProtocolMessageType('GetScratchpadStatusReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSCRATCHPADSTATUSREQ,
  '__module__' : 'otap_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.GetScratchpadStatusReq)
  })
_sym_db.RegisterMessage(GetScratchpadStatusReq)

GetScratchpadStatusResp = _reflection.GeneratedProtocolMessageType('GetScratchpadStatusResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSCRATCHPADSTATUSRESP,
  '__module__' : 'otap_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.GetScratchpadStatusResp)
  })
_sym_db.RegisterMessage(GetScratchpadStatusResp)

UploadScratchpadReq = _reflection.GeneratedProtocolMessageType('UploadScratchpadReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADSCRATCHPADREQ,
  '__module__' : 'otap_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.UploadScratchpadReq)
  })
_sym_db.RegisterMessage(UploadScratchpadReq)

UploadScratchpadResp = _reflection.GeneratedProtocolMessageType('UploadScratchpadResp', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADSCRATCHPADRESP,
  '__module__' : 'otap_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.UploadScratchpadResp)
  })
_sym_db.RegisterMessage(UploadScratchpadResp)

ProcessScratchpadReq = _reflection.GeneratedProtocolMessageType('ProcessScratchpadReq', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSSCRATCHPADREQ,
  '__module__' : 'otap_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.ProcessScratchpadReq)
  })
_sym_db.RegisterMessage(ProcessScratchpadReq)

ProcessScratchpadResp = _reflection.GeneratedProtocolMessageType('ProcessScratchpadResp', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSSCRATCHPADRESP,
  '__module__' : 'otap_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.ProcessScratchpadResp)
  })
_sym_db.RegisterMessage(ProcessScratchpadResp)

SetScratchpadTargetAndActionReq = _reflection.GeneratedProtocolMessageType('SetScratchpadTargetAndActionReq', (_message.Message,), {
  'DESCRIPTOR' : _SETSCRATCHPADTARGETANDACTIONREQ,
  '__module__' : 'otap_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.SetScratchpadTargetAndActionReq)
  })
_sym_db.RegisterMessage(SetScratchpadTargetAndActionReq)

SetScratchpadTargetAndActionResp = _reflection.GeneratedProtocolMessageType('SetScratchpadTargetAndActionResp', (_message.Message,), {
  'DESCRIPTOR' : _SETSCRATCHPADTARGETANDACTIONRESP,
  '__module__' : 'otap_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.SetScratchpadTargetAndActionResp)
  })
_sym_db.RegisterMessage(SetScratchpadTargetAndActionResp)


# @@protoc_insertion_point(module_scope)
