# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import wp_global_pb2 as wp__global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='data_message.proto',
  package='wirepas.proto.gateway_api',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12\x64\x61ta_message.proto\x12\x19wirepas.proto.gateway_api\x1a\x0fwp_global.proto\"\x82\x02\n\rSendPacketReq\x12\x38\n\x06header\x18\x01 \x02(\x0b\x32(.wirepas.proto.gateway_api.RequestHeader\x12\x1b\n\x13\x64\x65stination_address\x18\x02 \x02(\r\x12\x17\n\x0fsource_endpoint\x18\x03 \x02(\r\x12\x1c\n\x14\x64\x65stination_endpoint\x18\x04 \x02(\r\x12\x0b\n\x03qos\x18\x05 \x02(\r\x12\x0f\n\x07payload\x18\x06 \x02(\x0c\x12\x18\n\x10initial_delay_ms\x18\x07 \x01(\r\x12\x18\n\x10is_unack_csma_ca\x18\x08 \x01(\x08\x12\x11\n\thop_limit\x18\t \x01(\r\"K\n\x0eSendPacketResp\x12\x39\n\x06header\x18\x01 \x02(\x0b\x32).wirepas.proto.gateway_api.ResponseHeader\"\xcb\x02\n\x13PacketReceivedEvent\x12\x36\n\x06header\x18\x01 \x02(\x0b\x32&.wirepas.proto.gateway_api.EventHeader\x12\x16\n\x0esource_address\x18\x02 \x02(\r\x12\x1b\n\x13\x64\x65stination_address\x18\x03 \x02(\r\x12\x17\n\x0fsource_endpoint\x18\x04 \x02(\r\x12\x1c\n\x14\x64\x65stination_endpoint\x18\x05 \x02(\r\x12\x16\n\x0etravel_time_ms\x18\x06 \x02(\r\x12\x18\n\x10rx_time_ms_epoch\x18\x07 \x02(\x04\x12\x0b\n\x03qos\x18\x08 \x02(\r\x12\x0f\n\x07payload\x18\t \x01(\x0c\x12\x14\n\x0cpayload_size\x18\n \x01(\r\x12\x11\n\thop_count\x18\x0b \x01(\r\x12\x17\n\x0fnetwork_address\x18\x0c \x01(\x04'
  ,
  dependencies=[wp__global__pb2.DESCRIPTOR,])




_SENDPACKETREQ = _descriptor.Descriptor(
  name='SendPacketReq',
  full_name='wirepas.proto.gateway_api.SendPacketReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.SendPacketReq.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_address', full_name='wirepas.proto.gateway_api.SendPacketReq.destination_address', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_endpoint', full_name='wirepas.proto.gateway_api.SendPacketReq.source_endpoint', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_endpoint', full_name='wirepas.proto.gateway_api.SendPacketReq.destination_endpoint', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qos', full_name='wirepas.proto.gateway_api.SendPacketReq.qos', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='wirepas.proto.gateway_api.SendPacketReq.payload', index=5,
      number=6, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_delay_ms', full_name='wirepas.proto.gateway_api.SendPacketReq.initial_delay_ms', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_unack_csma_ca', full_name='wirepas.proto.gateway_api.SendPacketReq.is_unack_csma_ca', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hop_limit', full_name='wirepas.proto.gateway_api.SendPacketReq.hop_limit', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=325,
)


_SENDPACKETRESP = _descriptor.Descriptor(
  name='SendPacketResp',
  full_name='wirepas.proto.gateway_api.SendPacketResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.SendPacketResp.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=402,
)


_PACKETRECEIVEDEVENT = _descriptor.Descriptor(
  name='PacketReceivedEvent',
  full_name='wirepas.proto.gateway_api.PacketReceivedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_address', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.source_address', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_address', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.destination_address', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_endpoint', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.source_endpoint', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_endpoint', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.destination_endpoint', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='travel_time_ms', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.travel_time_ms', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_time_ms_epoch', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.rx_time_ms_epoch', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qos', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.qos', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.payload', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_size', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.payload_size', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hop_count', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.hop_count', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_address', full_name='wirepas.proto.gateway_api.PacketReceivedEvent.network_address', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=405,
  serialized_end=736,
)

_SENDPACKETREQ.fields_by_name['header'].message_type = wp__global__pb2._REQUESTHEADER
_SENDPACKETRESP.fields_by_name['header'].message_type = wp__global__pb2._RESPONSEHEADER
_PACKETRECEIVEDEVENT.fields_by_name['header'].message_type = wp__global__pb2._EVENTHEADER
DESCRIPTOR.message_types_by_name['SendPacketReq'] = _SENDPACKETREQ
DESCRIPTOR.message_types_by_name['SendPacketResp'] = _SENDPACKETRESP
DESCRIPTOR.message_types_by_name['PacketReceivedEvent'] = _PACKETRECEIVEDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SendPacketReq = _reflection.GeneratedProtocolMessageType('SendPacketReq', (_message.Message,), {
  'DESCRIPTOR' : _SENDPACKETREQ,
  '__module__' : 'data_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.SendPacketReq)
  })
_sym_db.RegisterMessage(SendPacketReq)

SendPacketResp = _reflection.GeneratedProtocolMessageType('SendPacketResp', (_message.Message,), {
  'DESCRIPTOR' : _SENDPACKETRESP,
  '__module__' : 'data_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.SendPacketResp)
  })
_sym_db.RegisterMessage(SendPacketResp)

PacketReceivedEvent = _reflection.GeneratedProtocolMessageType('PacketReceivedEvent', (_message.Message,), {
  'DESCRIPTOR' : _PACKETRECEIVEDEVENT,
  '__module__' : 'data_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.PacketReceivedEvent)
  })
_sym_db.RegisterMessage(PacketReceivedEvent)


# @@protoc_insertion_point(module_scope)
