"""
    Wirepas exceptions
    ==================

    .. Copyright:
        Copyright 2019 Wirepas Ltd under Apache License, Version 2.0.
        See file LICENSE for full license details.
"""


class GatewayAPIParsingException(Exception):
    """
    Wirepas Gateway API generic Exception
    """
